==> gorilla-notebook-0.4.6.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.storage.direct.repo.js <==
goog.provide('pinkgorilla.storage.direct.repo');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('goog.crypt.base64');
goog.require('pinkgorilla.storage.direct.direct');
goog.require('pinkgorilla.storage.repo');
(pinkgorilla.storage.repo.StorageRepo.prototype.pinkgorilla$storage$direct$direct$Direct$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.repo.StorageRepo.prototype.pinkgorilla$storage$direct$direct$Direct$load_url$arity$2 = (function (self,base_path){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.direct.repo","/tmp/form-init1931319452997354739.clj",12,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["repo-storage.load-url"], null);
}),null)),null,-998031112);

return ["https://api.github.com/repos/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.user),"/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.repo),"/contents/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.filename)].join('');
}));

(pinkgorilla.storage.repo.StorageRepo.prototype.pinkgorilla$storage$direct$direct$Direct$decode_content$arity$2 = (function (self,response){
var self__$1 = this;
var G__55437 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(response,"content");
return goog.crypt.base64.decodeString(G__55437);
}));

//# sourceMappingURL=pinkgorilla.storage.direct.repo.js.map

==> gorilla-notebook-0.4.7.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.storage.direct.repo.js <==
goog.provide('pinkgorilla.storage.direct.repo');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('goog.crypt.base64');
goog.require('pinkgorilla.storage.direct.direct');
goog.require('pinkgorilla.storage.repo');
(pinkgorilla.storage.repo.StorageRepo.prototype.pinkgorilla$storage$direct$direct$Direct$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.repo.StorageRepo.prototype.pinkgorilla$storage$direct$direct$Direct$load_url$arity$2 = (function (self,base_path){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.direct.repo","/tmp/form-init2057653484232335990.clj",12,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["repo-storage.load-url"], null);
}),null)),null,1182055010);

return ["https://api.github.com/repos/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.user),"/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.repo),"/contents/",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.filename)].join('');
}));

(pinkgorilla.storage.repo.StorageRepo.prototype.pinkgorilla$storage$direct$direct$Direct$decode_content$arity$2 = (function (self,response){
var self__$1 = this;
var G__55437 = cljs.core.get.cljs$core$IFn$_invoke$arity$2(response,"content");
return goog.crypt.base64.decodeString(G__55437);
}));

//# sourceMappingURL=pinkgorilla.storage.direct.repo.js.map
